==> invoice-client-4.1.44-20230109.125546-5-sources.jar: com/xforceplus/seller/invoice/client/model/RemarkFieldMetadata.java <==
package com.xforceplus.seller.invoice.client.model;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

@ApiModel
public class RemarkFieldMetadata {

    @ApiModelProperty("字段名")
    private String fieldName = null;

    @ApiModelProperty("字段显示名称")
    private String fieldDisplayName = null;

    @ApiModelProperty("字段所属group")
    private String fieldGroup = null;

    @ApiModelProperty("字段所属group名称")
    private String fieldGroupName = null;

    @ApiModelProperty("字段所属group Index")
    private Integer fieldGroupIndex = 0;

    @ApiModelProperty("字段类型")
    private String fieldType = null;

    public String getFieldName() {
        return fieldName;
    }

    public void setFieldName(String fieldName) {
        this.fieldName = fieldName;
    }

    public String getFieldDisplayName() {
        return fieldDisplayName;
    }

    public void setFieldDisplayName(String fieldDisplayName) {
        this.fieldDisplayName = fieldDisplayName;
    }

    public String getFieldGroup() {
        return fieldGroup;
    }

    public void setFieldGroup(String fieldGroup) {
        this.fieldGroup = fieldGroup;
    }

    public String getFieldGroupName() {
        return fieldGroupName;
    }

    public void setFieldGroupName(String fieldGroupName) {
        this.fieldGroupName = fieldGroupName;
    }

    public Integer getFieldGroupIndex() {
        return fieldGroupIndex;
    }

    public void setFieldGroupIndex(Integer fieldGroupIndex) {
        this.fieldGroupIndex = fieldGroupIndex;
    }

    public String getFieldType() {
        return fieldType;
    }

    public void setFieldType(String fieldType) {
        this.fieldType = fieldType;
    }
}

==> invoice-client-4.1.54-20231220.064452-5-sources.jar: com/xforceplus/seller/invoice/client/model/RemarkFieldMetadata.java <==
package com.xforceplus.seller.invoice.client.model;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

@ApiModel
public class RemarkFieldMetadata {

    @ApiModelProperty("字段名")
    private String fieldName = null;

    @ApiModelProperty("字段显示名称")
    private String fieldDisplayName = null;

    @ApiModelProperty("字段所属group")
    private String fieldGroup = null;

    @ApiModelProperty("字段所属group名称")
    private String fieldGroupName = null;

    @ApiModelProperty("字段所属group Index")
    private Integer fieldGroupIndex = 0;

    @ApiModelProperty("字段类型")
    private String fieldType = null;

    @ApiModelProperty(value = "字段类型 0-字段值 1-固定值", allowableValues = "0, 1")
    private int type;

    @ApiModelProperty("固定值")
    private java.lang.String fieldFixedValue;

    public int getType() {
        return type;
    }

    public void setType(int type) {
        this.type = type;
    }

    public String getFieldFixedValue() {
        return fieldFixedValue;
    }

    public void setFieldFixedValue(String fieldFixedValue) {
        this.fieldFixedValue = fieldFixedValue;
    }

    public String getFieldName() {
        return fieldName;
    }

    public void setFieldName(String fieldName) {
        this.fieldName = fieldName;
    }

    public String getFieldDisplayName() {
        return fieldDisplayName;
    }

    public void setFieldDisplayName(String fieldDisplayName) {
        this.fieldDisplayName = fieldDisplayName;
    }

    public String getFieldGroup() {
        return fieldGroup;
    }

    public void setFieldGroup(String fieldGroup) {
        this.fieldGroup = fieldGroup;
    }

    public String getFieldGroupName() {
        return fieldGroupName;
    }

    public void setFieldGroupName(String fieldGroupName) {
        this.fieldGroupName = fieldGroupName;
    }

    public Integer getFieldGroupIndex() {
        return fieldGroupIndex;
    }

    public void setFieldGroupIndex(Integer fieldGroupIndex) {
        this.fieldGroupIndex = fieldGroupIndex;
    }

    public String getFieldType() {
        return fieldType;
    }

    public void setFieldType(String fieldType) {
        this.fieldType = fieldType;
    }
}
